==> oxide-qt_1.17.9.orig.tar.xz: oxide-qt-1.17.9/oxide/shared/browser/oxide_browser_platform_integration.h <==
// vim:expandtab:shiftwidth=2:tabstop=2:
// Copyright (C) 2014-2015 Canonical Ltd.

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_
#define _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_

#include <memory>
#include <string>

#include "base/macros.h"
#include "base/observer_list.h"
#include "content/public/browser/browser_thread.h"
#include "device/vibration/vibration_manager_impl.h"

#include "shared/common/oxide_shared_export.h"

class GURL;

namespace content {
class LocationProvider;
}

namespace oxide {

class BrowserPlatformIntegrationObserver;
class Clipboard;
class DragSource;
class DragSourceClient;
class GLContextDependent;
class MessagePump;
class ScreenClient;

// An abstract interface allowing toolkit-independent code to integrate with
// toolkit-specific features
class OXIDE_SHARED_EXPORT BrowserPlatformIntegration {
 public:
  virtual ~BrowserPlatformIntegration();

  enum ApplicationState {
    // The application is about to be suspended
    APPLICATION_STATE_SUSPENDED,

    // The application is running but has no focused windows.
    // XXX: It's not clear whether anything really needs to distinguish
    //      between this and ACTIVE
    APPLICATION_STATE_INACTIVE,

    // The application is running and has a focused window
    APPLICATION_STATE_ACTIVE
  };

  // Can be called on any thread. Destruction of this class
  // must only happen once all Chromium threads have been shut down
  static BrowserPlatformIntegration* GetInstance();

  // Launch |url| in an external application. Can be called on any thread
  virtual bool LaunchURLExternally(const GURL& url);

  // Determine if there are any touch devices connected. Called on the UI
  // thread
  virtual bool IsTouchSupported();

  // Return a native display handle that can be used to create GL contexts.
  // Called on the UI thread
  virtual intptr_t GetNativeDisplay() = 0;

  // Get the ScreenClient implementation. Can be called on any thread
  // FIXME(chrisccoulson): Make this UI thread only
  virtual ScreenClient* GetScreenClient() = 0;

  // Return the shared GL context provided by the application, if one exists.
  // This will be used for sharing resources between the webview and UI
  // compositors. Called on the UI thread
  virtual GLContextDependent* GetGLShareContext();

  // Create a MessagePump that allows Chromium events to be pumped from
  // the applications UI event loop
  virtual std::unique_ptr<MessagePump> CreateUIMessagePump() = 0;

  // Create a Clipboard implementation
  virtual Clipboard* CreateClipboard();

  // Called on the specified browser thread
  virtual void BrowserThreadInit(content::BrowserThread::ID id);
  virtual void BrowserThreadCleanUp(content::BrowserThread::ID id);

  // Create a LocationProvider for determining location information from
  // the toolkit. Can return nullptr. Called on the geolocation thread
  virtual std::unique_ptr<content::LocationProvider> CreateLocationProvider();

  // Get the current application state. Called on the UI thread
  virtual ApplicationState GetApplicationState();

  // Time limit, in milliseconds, to distinguish between aggregate or just
  // successive mouse click events. 
  virtual int GetClickInterval() = 0;

  // Get the application name. Can be called on any thread
  virtual std::string GetApplicationName();

  // Create a new DragSource implementation. Ownership of |client| is not
  // transferred, and |client| will outlive the returned DragSource.
  // Called on the UI thread
  virtual std::unique_ptr<DragSource> CreateDragSource(DragSourceClient* client);

  // Get the proper vibration manager factory
  virtual void CreateVibrationManager(
      mojo::InterfaceRequest<device::VibrationManager> request);

 protected:
  BrowserPlatformIntegration();

  void NotifyApplicationStateChanged();

 private:
  friend class BrowserPlatformIntegrationObserver;

  void AddObserver(BrowserPlatformIntegrationObserver* observer);
  void RemoveObserver(BrowserPlatformIntegrationObserver* observer);

  base::ObserverList<BrowserPlatformIntegrationObserver> observers_;

  DISALLOW_COPY_AND_ASSIGN(BrowserPlatformIntegration);
};

} // namespace oxide

#endif // _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_

==> oxide-qt_1.21.5.orig.tar.xz: oxide-qt-1.21.5/oxide/shared/browser/oxide_browser_platform_integration.h <==
// vim:expandtab:shiftwidth=2:tabstop=2:
// Copyright (C) 2014-2015 Canonical Ltd.

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_
#define _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_

#include <memory>
#include <string>

#include "base/macros.h"
#include "base/observer_list.h"
#include "content/public/browser/browser_thread.h"
#include "device/vibration/vibration_manager_impl.h"

#include "shared/common/oxide_shared_export.h"

class GURL;

namespace device {
class LocationProvider;
}

namespace oxide {

class BrowserPlatformIntegrationObserver;
class Clipboard;
class DragSource;
class DragSourceClient;
class GLContextDependent;
class MessagePump;
class Screen;

// An abstract interface allowing toolkit-independent code to integrate with
// toolkit-specific features
class OXIDE_SHARED_EXPORT BrowserPlatformIntegration {
 public:
  virtual ~BrowserPlatformIntegration();

  enum ApplicationState {
    // The application is about to be suspended
    APPLICATION_STATE_SUSPENDED,

    // The application is running but has no focused windows.
    // XXX: It's not clear whether anything really needs to distinguish
    //      between this and ACTIVE
    APPLICATION_STATE_INACTIVE,

    // The application is running and has a focused window
    APPLICATION_STATE_ACTIVE
  };

  // Can be called on any thread. Destruction of this class
  // must only happen once all Chromium threads have been shut down
  static BrowserPlatformIntegration* GetInstance();

  // Launch |url| in an external application. Can be called on any thread
  virtual bool LaunchURLExternally(const GURL& url);

  // Determine if there are any touch devices connected. Called on the UI
  // thread
  virtual bool IsTouchSupported();

  // Return a native display handle that can be used to create GL contexts.
  // Called on the UI thread
  virtual intptr_t GetNativeDisplay() = 0;

  // Get the Screen implementation. Can be called on any thread
  // FIXME(chrisccoulson): Make this UI thread only
  virtual Screen* GetScreen() = 0;

  // Return the shared GL context provided by the application, if one exists.
  // This will be used for sharing resources between the webview and UI
  // compositors. Called on the UI thread
  virtual GLContextDependent* GetGLShareContext();

  // Create a MessagePump that allows Chromium events to be pumped from
  // the applications UI event loop
  virtual std::unique_ptr<MessagePump> CreateUIMessagePump() = 0;

  // Create a Clipboard implementation
  virtual Clipboard* CreateClipboard();

  // Called on the specified browser thread
  virtual void BrowserThreadInit(content::BrowserThread::ID id);
  virtual void BrowserThreadCleanUp(content::BrowserThread::ID id);

  // Create a LocationProvider for determining location information from
  // the toolkit. Can return nullptr. Called on the geolocation thread
  virtual std::unique_ptr<device::LocationProvider> CreateLocationProvider();

  // Get the current application state. Called on the UI thread
  virtual ApplicationState GetApplicationState();

  // Time limit, in milliseconds, to distinguish between aggregate or just
  // successive mouse click events. 
  virtual int GetClickInterval() = 0;

  // Get the application name. Can be called on any thread
  virtual std::string GetApplicationName();

  // Create a new DragSource implementation. Ownership of |client| is not
  // transferred, and |client| will outlive the returned DragSource.
  // Called on the UI thread
  virtual std::unique_ptr<DragSource> CreateDragSource(DragSourceClient* client);

  // Get the proper vibration manager factory
  virtual void CreateVibrationManager(
      mojo::InterfaceRequest<device::VibrationManager> request);

 protected:
  BrowserPlatformIntegration();

  void NotifyApplicationStateChanged();

 private:
  friend class BrowserPlatformIntegrationObserver;

  void AddObserver(BrowserPlatformIntegrationObserver* observer);
  void RemoveObserver(BrowserPlatformIntegrationObserver* observer);

  base::ObserverList<BrowserPlatformIntegrationObserver> observers_;

  DISALLOW_COPY_AND_ASSIGN(BrowserPlatformIntegration);
};

} // namespace oxide

#endif // _OXIDE_SHARED_BROWSER_PLATFORM_INTEGRATION_H_
